@@ -29,7 +29,6 @@ sub distribution {
 }
 
 sub meta_merge {
-    my ( undef, @extra ) = @_;
     return {
 	'meta-spec'	=> {
 	    version	=> 2,
@@ -40,7 +39,7 @@ sub meta_merge {
 	},
 	resources	=> {
 	    bugtracker	=> {
-		web	=> 'https://github.com/trwyant/perl-Astro-Coord-ECI/issues',
+		web	=> 'https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-satpass',
                 mailto  => 'wyant@cpan.org',
 	    },
 	    license	=> 'http://dev.perl.org/licenses/',
@@ -49,22 +48,10 @@ sub meta_merge {
 		url	=> 'git://github.com/trwyant/perl-Astro-Coord-ECI.git',
 		web	=> 'https://github.com/trwyant/perl-Astro-Coord-ECI',
 	    },
-	},
-	@extra,
+	}
     };
 }
 
-sub provides {
-    -d 'lib'
-	or return;
-    local $@ = undef;
-    my $provides = eval {
-	require Module::Metadata;
-	Module::Metadata->provides( version => 2, dir => 'lib' );
-    } or return;
-    return ( provides => $provides );
-}
-
 sub requires {
     my ( undef, @extra ) = @_;		# Invocant unused
 ##  if ( ! $self->distribution() ) {
@@ -75,9 +62,8 @@ sub requires {
 	'Exporter'	=> 5.64,
 	'IO::File'	=> 0,
 	'POSIX'		=> 0,
-	'Scalar::Util'	=> 1.22,	# For looks_like_number
+	'Scalar::Util'	=> 0,
 	'Storable'	=> 0,
-	'base'		=> 0,
 	'constant'	=> 0,
 	'strict'	=> 0,
 	'warnings'	=> 0,
@@ -154,18 +140,6 @@ has to be provided by making use of the builder's C<meta_merge>
 functionality. This includes the C<dynamic_config>, C<no_index> and
 C<resources> data.
 
-Any arguments will be appended to the generated array.
-
-=head2 provides
-
- use YAML;
- print Dump( [ $meta->provides() ] );
-
-This method attempts to load L<Module::Metadata|Module::Metadata>. If
-this succeeds, it returns a C<provides> entry suitable for inclusion in
-L<meta_merge()|/meta_merge> data (i.e. C<'provides'> followed by a hash
-reference). If it can not load the required module, it returns nothing.
-
 =head2 requires
 
  use YAML;
@@ -202,8 +176,7 @@ information makes it into F<META.yml>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://github.com/trwyant/perl-Astro-Coord-ECI/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -211,7 +184,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2020 by Thomas R. Wyant, III
+Copyright (C) 2010-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
